/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Takeshi Kurosawa
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * Robert Longson <longsonr@gmail.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIDOMCSS2Properties.idl"

[scriptable, uuid(b555e226-a387-4953-b2bc-c77296d146ec)]
interface nsIDOMSVGCSS2Properties : nsIDOMCSS2Properties
{
           /* SVG CSS properties */
           attribute DOMString        clipPath;
                                        // raises(DOMException) on setting

           attribute DOMString        clipRule;
                                        // raises(DOMException) on setting

           attribute DOMString        colorInterpolation;
                                        // raises(DOMException) on setting

           attribute DOMString        colorInterpolationFilters;
                                        // raises(DOMException) on setting

           attribute DOMString        dominantBaseline;
                                        // raises(DOMException) on setting

           attribute DOMString        fill;
                                        // raises(DOMException) on setting

           attribute DOMString        fillOpacity;
                                        // raises(DOMException) on setting

           attribute DOMString        fillRule;
                                        // raises(DOMException) on setting

           attribute DOMString        filter;
                                        // raises(DOMException) on setting

           attribute DOMString        floodColor;
                                        // raises(DOMException) on setting

           attribute DOMString        floodOpacity;
                                        // raises(DOMException) on setting

           attribute DOMString        imageRendering;
                                        // raises(DOMException) on setting

           attribute DOMString        lightingColor;
                                        // raises(DOMException) on setting

           attribute DOMString        marker;
                                        // raises(DOMException) on setting

           attribute DOMString        markerEnd;
                                        // raises(DOMException) on setting

           attribute DOMString        markerMid;
                                        // raises(DOMException) on setting

           attribute DOMString        markerStart;
                                        // raises(DOMException) on setting

           attribute DOMString        mask;
                                        // raises(DOMException) on setting

           attribute DOMString        shapeRendering;
                                        // raises(DOMException) on setting

           attribute DOMString        stopColor;
                                        // raises(DOMException) on setting

           attribute DOMString        stopOpacity;
                                        // raises(DOMException) on setting

           attribute DOMString        stroke;
                                        // raises(DOMException) on setting

           attribute DOMString        strokeDasharray;
                                        // raises(DOMException) on setting

           attribute DOMString        strokeDashoffset;
                                        // raises(DOMException) on setting

           attribute DOMString        strokeLinecap;
                                        // raises(DOMException) on setting

           attribute DOMString        strokeLinejoin;
                                        // raises(DOMException) on setting

           attribute DOMString        strokeMiterlimit;
                                        // raises(DOMException) on setting

           attribute DOMString        strokeOpacity;
                                        // raises(DOMException) on setting

           attribute DOMString        strokeWidth;
                                        // raises(DOMException) on setting

           attribute DOMString        textAnchor;
                                        // raises(DOMException) on setting

           attribute DOMString        textRendering;
                                        // raises(DOMException) on setting
};
